@@ -6,22 +6,20 @@ use Moo;
 
 has path  => (is => 'ro', required => 1);
 has key   => (is => 'ro', required => 1);
-has guard => (is => 'ro');
 
 around BUILDARGS => sub {
     my ($orig, $class, $path) = @_;
-    my ($p, $key, $guard) = parse_data_path($path);
-    $orig->($class, path => $p, key => $key, guard => $guard);
+    my ($p, $key) = parse_data_path($path);
+    $orig->($class, path => $p, key => $key);
 };
 
 sub fix {
     my ($self, $data) = @_;
 
     my $key = $self->key;
-    my $guard = $self->guard;
     for my $match (grep ref, data_at($self->path, $data)) {
         set_data($match, $key,
-            map { $guard->($_) && is_string($_) ? lc(as_utf8($_)) : $_ }
+            map { is_string($_) ? lc(as_utf8($_)) : $_ }
                 get_data($match, $key));
     }
 
